@@ -22,7 +22,7 @@ copyright = '2020, Edward Rogers'
 author = 'Edward Rogers'
 
 # The full version, including alpha/beta/rc tags
-release = '1.0'
+release = ''
 
 master_doc = 'index'
 
@@ -71,3 +71,5 @@ html_theme = 'sphinx_rtd_theme'
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
 html_static_path = ['_static']
+
+html_title = 'PyHank documentation'
